@@ -15,7 +15,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 
 # Some global variables we use
 source = None
@@ -342,7 +342,7 @@ def closestServers(client, all=False):
     distance
     """
 
-    uh = urlopen('http://c.speedtest.net/speedtest-servers-static.php')
+    uh = urlopen('http://www.speedtest.net/speedtest-servers-static.php')
     serversxml = []
     while 1:
         serversxml.append(uh.read(10240))
@@ -412,7 +412,7 @@ def getBestServer(servers):
                 h.request("GET", urlparts[2])
                 r = h.getresponse()
                 total = (timeit.default_timer() - start)
-            except (HTTPError, URLError):
+            except (HTTPError, URLError, socket.error):
                 cum.append(3600)
                 continue
             text = r.read(9)
